@@ -1063,7 +1063,7 @@ void sentence_delete(Sentence sent)
 	free_effective_dist(sent);
 	free_count(sent);
 	free_analyze(sent);
-	xfree(sent->is_conjunction, sizeof(char)*sent->length);
+	if (sent->is_conjunction) xfree(sent->is_conjunction, sizeof(char)*sent->length);
 	xfree((char *) sent, sizeof(struct Sentence_s));
 }
 
@@ -1140,7 +1140,7 @@ int sentence_parse(Sentence sent, Parse_Options opts)
 	verbosity = opts->verbosity;
 
 	rc = split_sentence(sent, opts);
-	if (rc) return 0;
+	if (rc) return -1;
 
 	/* Tokenize, look up each word in the dictionary, collect up all
 	 * plausible disjunct expressions for each word. */
