@@ -103,17 +103,9 @@
 #define ANDABLE_CONNECTORS_WORD ("ANDABLE-CONNECTORS")
 #define UNLIMITED_CONNECTORS_WORD ("UNLIMITED-CONNECTORS")
 
-/*
-OBS #define COMMA_WORD       ("COMMA")
-OBS #define COLON_WORD       ("COLON")
-OBS #define SEMICOLON_WORD   ("SEMI-COLON")
-OBS #define PERCENT_WORD     ("PERCENT-SIGN")
-OBS #define DOLLAR_WORD      ("DOLLAR-SIGN")
-OBS #define LP_WORD          ("LEFT-PAREN")
-OBS #define RP_WORD          ("RIGHT-PAREN")
-OBS #define AMPERSAND_WORD   ("AMPERSAND")
-*/
-
+#if DONT_USE_REGEX_GUESSING
+/* English-language-specific morphology guessing */
+/* Obsolete, replaced by regex-based morphology handler */
 #define PROPER_WORD      ("CAPITALIZED-WORDS")
 #define PL_PROPER_WORD      ("PL-CAPITALIZED-WORDS")
 #define HYPHENATED_WORD  ("HYPHENATED-WORDS")
@@ -122,6 +114,8 @@ OBS #define AMPERSAND_WORD   ("AMPERSAND")
 #define S_WORD           ("S-WORDS")
 #define ED_WORD          ("ED-WORDS")
 #define LY_WORD          ("LY-WORDS")
+#endif /* DONT_USE_REGEX_GUESSING */
+
 #define UNKNOWN_WORD     ("UNKNOWN-WORD")
 
 #define MAX_PATH_NAME 200     /* file names (including paths)
@@ -282,6 +276,20 @@ struct Dict_node_struct
     Dict_node *left, *right;
 };
 
+/* The regexs are stored as a linked list of the following nodes. */
+struct Regex_node_s
+{
+    char *name;      /* The identifying name of the regex */
+    char *pattern;   /* The regular expression pattern */
+    void *re;        /* The compiled regex. void * to avoid
+                      * having re library details invading the
+                      * rest of the LG system; regex-morph.c
+                      * takes care of all matching.
+                      */
+    Regex_node *next;
+};
+
+
 /* The following three structs comprise what is returned by post_process(). */
 typedef struct D_type_list_struct D_type_list;
 struct D_type_list_struct
